@@ -879,6 +879,9 @@ void       gts_bb_tree_destroy               (GNode * tree,
 
 typedef struct _GtsSurfaceStats        GtsSurfaceStats;
 typedef struct _GtsSurfaceQualityStats GtsSurfaceQualityStats;
+typedef GtsVertex * (*GtsRefineFunc)   (GtsEdge * e,
+					GtsVertexClass * klass,
+					gpointer data);
 typedef GtsVertex * (*GtsCoarsenFunc)  (GtsEdge * e,
 					GtsVertexClass * klass,
 					gpointer data);
@@ -980,6 +983,8 @@ void         gts_surface_traverse_destroy  (GtsSurfaceTraverse * t);
 void         gts_surface_refine            (GtsSurface * surface,
 					    GtsKeyFunc cost_func,
 					    gpointer cost_data,
+					    GtsRefineFunc refine_func,
+					    gpointer refine_data,
 					    GtsStopFunc stop_func,
 					    gpointer stop_data);
 gboolean     gts_edge_collapse_is_valid    (GtsEdge * e);
@@ -997,6 +1002,11 @@ gboolean     gts_coarsen_stop_number       (gdouble cost,
 gboolean     gts_coarsen_stop_cost         (gdouble cost, 
 					    guint nedge, 
 					    gdouble * max_cost);
+void         gts_surface_tessellate        (GtsSurface * s,
+					    GtsRefineFunc refine_func,
+					    gpointer refine_data);
+GtsSurface * gts_surface_generate_sphere   (GtsSurface * s,
+					    guint geodesation_order);
 GtsSurface * gts_surface_copy              (GtsSurface * s1,
 					    GtsSurface * s2);
 void         gts_surface_merge             (GtsSurface * s, 
